******************************************************************************
*** Program: Inbox2Dbf
*** Time Stamp:   07/31/02 08:26:02 PM
*** Instantiates the custom class defined in this program for automating outlook 2000.
*** Includes functionality to read 
*** messages from the Outlook Inbox and store them in OlMail.dbf
******************************************************************************
LOCAL loMail, loRootFolder

loMail = CREATEOBJECT( 'sesOutlook' )
IF VARTYPE( loMail ) = 'O'
	WITH loMail
		loRootFolder = .oNameSpace.Folders(1)
		IF .ReadMail( loRootFolder )
			SET DATASESSION TO loMail.DataSessionID
			SELECT SaveMail
			BROWSE LAST
		ENDIF
	ENDWITH
ENDIF
RETURN
			
DEFINE CLASS sesOutlook AS Session

	*** Object reference to the outlook application object
	oOutlook = .NULL.
	*** Object reference to the MAPI namespace object in Outlook from which you reference all the other objects (like the inbox)
	oNamespace = .NULL.

  *******************************************************************************************************
	FUNCTION CreateSession()
  *******************************************************************************************************
	*** Instantiate outlook and logon
		LOCAL llRetVal

		*** See we we already have an instance of Outlook Running
		IF TYPE( 'This.oOutlook' ) = 'O' AND NOT ISNULL( This.oOutlook )
			*** No need to create a new instance
		ELSE
			WITH This
				.oOutLook = CREATEOBJECT( 'Outlook.Application' )
				IF TYPE( 'This.oOutLook' ) = 'O' AND NOT ISNULL( .oOutlook )
					.oNameSpace = .oOutlook.GetNameSpace( 'MAPI' )
					IF TYPE( 'This.oNameSpace' ) = 'O' AND NOT ISNULL( .oNameSpace )
						llRetVal = .T.
					ENDIF
				ENDIF
			ENDWITH
		ENDIF

		RETURN llRetVal
	ENDFUNC

  *******************************************************************************************************
	FUNCTION OpenMsgTables()
  *******************************************************************************************************
		WITH This
			IF NOT USED( 'SaveMail' )
				USE SaveMail AGAIN IN 0
			ENDIF
			IF NOT USED( 'OlAttach' )
				USE SaveAttach AGAIN IN 0
			ENDIF
		ENDWITH
	ENDFUNC
		
  *******************************************************************************************************
	FUNCTION ReadMail( toFolder )
  *******************************************************************************************************
		*** The ReadMail Method goes through all the Outlook folders recursively and save all 
		*** of the mailItems to the table OlMail.dbf. If the message has any attachments, 
		*** it then calls the SaveAttachments method to save the attachment as a file on disk and 
		*** insert a record with the name of the file into OlAttach.dbf along with a foreign key 
		*** to the message in OlMail.dbf
		LOCAL loItems, loItem, loFolders, loFolder

		*** Get a local referenece to the collection of of items in the current folder
		loItems = toFolder.Items

		*** Process all the items in the current folder
		*** If it is a mail item, save it and process the attachments
		IF VARTYPE( loItems ) = 'O'
			FOR EACH loItem IN loItems
				IF 	loItem.Class = 	43		&& olMail	
					*** Add a record to the messages tabel
					INSERT INTO SaveMail ( omInDate, omSender, omSubject, omBody, omFolder ) ;
						VALUES ( loItem.ReceivedTime, loItem.SenderName, loItem.Subject, loItem.Body, toFolder.Name )
					*** Now see if we have attachments
					IF loItem.Attachments.Count > 0
						This.SaveAttachments( loItem )
					ENDIF
				ENDIF
			ENDFOR
		ENDIF

		*** Now see if this folder has folders to process
		IF toFolder.Class = 2	&&	olFolder	
			loFolders = toFolder.Folders
			FOR EACH loFolder IN loFolders
				This.ReadMail( loFolder )
			ENDFOR
		ENDIF
		
		RETURN 
	ENDFUNC

	*******************************************************************************************************
	FUNCTION SaveAttachments( toMsg )
  *******************************************************************************************************
		LOCAL	loAttachment,  lcFileName

		*** Saves the attachmens associated with the current message to the specified file name
		FOR EACH loAttachment IN toMsg.Attachments
			lcFileName = FULLPATH( CURDIR() ) + loAttachment.FileName
			loAttachment.SaveAsFile( lcFileName )
			*** Make sure it was saved
			*** The SaveAsFile method returns null...it doesn't tell us about success or failure
			IF FILE( lcFileName )
				*** ok...now add it to the table
				INSERT INTO SaveAttach ( omMailFK, attFname ) VALUES ( SaveMail.omMailPK, lcFileName )
			ENDIF
		ENDFOR
	ENDFUNC


  *******************************************************************************************************
	FUNCTION Destroy()
  *******************************************************************************************************
		WITH This
			.oNameSpace = .NULL.
			.oOutLook = .NULL.
		ENDWITH
	ENDFUNC


  *******************************************************************************************************
	FUNCTION Init()
  *******************************************************************************************************
		LOCAL llRetVal
		llRetVal = DODEFAULT()
		
		IF llRetVal
			llRetVal = This.CreateSession( )
		ENDIF
		
		IF llRetVal
			This.OpenMsgTables()
		ENDIF

		RETURN llRetVal

	ENDFUNC


ENDDEFINE
*** EndDefine: sesOutlook

